@@ -120,31 +120,32 @@ test_that('unidimensional', {
     
     exposure <- rep(3L, nrow(df2))
     set.seed(1234)
+    start_item=sample(c(1:nrow(df2)), 1)
     res <- mirtCAT(df2, mod, local_pattern=pat, criteria='MI',
                    design = list(min_SEM = .4, exposure=exposure), method = 'EAP', 
-                   start_item=sample(c(1:nrow(df2)), 1))
-    expect_equal(as.numeric(res$thetas), -0.0109594, tolerance = 1e-4)
+                   start_item=start_item)
+    expect_equal(as.numeric(res$thetas), -0.2246403, tolerance = 1e-4)
     so <- summary(res)
-    expect_equal(so$items_answered, c(3,20,15,2,5,24,14,6,21,19,22,11))
+    expect_equal(so$items_answered, c(3,15,20,2,14,21,9,24,5,19,6,22))
     expect_equal(as.numeric(so$thetas_SE_history[nrow(so$thetas_SE_history),]),
-                 0.3850345, tolerance = 1e-4)
+                 0.398947, tolerance = 1e-4)
     
     set.seed(1)
     exposure <- rep(0.75, nrow(df2))
     res <- mirtCAT(df2, mod, local_pattern=pat, criteria='MI',
                    design = list(min_SEM = .4, exposure=exposure), method = 'EAP', 
                    start_item=sample(c(1:nrow(df2)), 1))
-    expect_equal(as.numeric(res$thetas), -.03342287, tolerance = 1e-4)
+    expect_equal(as.numeric(res$thetas), .1408694, tolerance = 1e-4)
     so <- summary(res)
     expect_equal(as.numeric(so$thetas_SE_history[nrow(so$thetas_SE_history),]),
-                 0.3986095, tolerance = 1e-4)
+                 0.3992262, tolerance = 1e-4)
     
     set.seed(12)
     res <- mirtCAT(df2, mod, local_pattern=pat, 
                    design = list(min_SEM = .4), method = 'EAP', criteria='random')
-    expect_equal(as.numeric(res$thetas), 0.07423068, tolerance = 1e-4)
+    expect_equal(as.numeric(res$thetas), -.1665438, tolerance = 1e-4)
     expect_equal(as.numeric(res$thetas_SE_history[nrow(res$thetas_SE_history),]),
-                 0.3915826, tolerance = 1e-4)
+                 0.3859334, tolerance = 1e-4)
     
     res <- mirtCAT(df2, mod, local_pattern=pat, 
                    design = list(min_SEM = .4), method = 'EAP', criteria='MEI')
